@@ -23,68 +23,58 @@ from aliyunsdkslb.endpoint import endpoint_data
 class SetTLSCipherPolicyAttributeRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Slb', '2014-05-15', 'SetTLSCipherPolicyAttribute','slb')
+		RpcRequest.__init__(self, 'Slb', '2014-05-15', 'SetTLSCipherPolicyAttribute','Slb')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_access_key_id(self):
+	def get_access_key_id(self): # String
 		return self.get_query_params().get('access_key_id')
 
-	def set_access_key_id(self,access_key_id):
-		self.add_query_param('access_key_id',access_key_id)
-
-	def get_ResourceOwnerId(self):
+	def set_access_key_id(self, access_key_id):  # String
+		self.add_query_param('access_key_id', access_key_id)
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_TLSCipherPolicyId(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_TLSCipherPolicyId(self): # String
 		return self.get_query_params().get('TLSCipherPolicyId')
 
-	def set_TLSCipherPolicyId(self,TLSCipherPolicyId):
-		self.add_query_param('TLSCipherPolicyId',TLSCipherPolicyId)
-
-	def get_Cipherss(self):
+	def set_TLSCipherPolicyId(self, TLSCipherPolicyId):  # String
+		self.add_query_param('TLSCipherPolicyId', TLSCipherPolicyId)
+	def get_Cipherss(self): # RepeatList
 		return self.get_query_params().get('Ciphers')
 
-	def set_Cipherss(self, Cipherss):
-		for depth1 in range(len(Cipherss)):
-			if Cipherss[depth1] is not None:
-				self.add_query_param('Ciphers.' + str(depth1 + 1) , Cipherss[depth1])
-
-	def get_TLSVersionss(self):
+	def set_Cipherss(self, Ciphers):  # RepeatList
+		for depth1 in range(len(Ciphers)):
+			self.add_query_param('Ciphers.' + str(depth1 + 1), Ciphers[depth1])
+	def get_TLSVersionss(self): # RepeatList
 		return self.get_query_params().get('TLSVersions')
 
-	def set_TLSVersionss(self, TLSVersionss):
-		for depth1 in range(len(TLSVersionss)):
-			if TLSVersionss[depth1] is not None:
-				self.add_query_param('TLSVersions.' + str(depth1 + 1) , TLSVersionss[depth1])
-
-	def get_ResourceOwnerAccount(self):
+	def set_TLSVersionss(self, TLSVersions):  # RepeatList
+		for depth1 in range(len(TLSVersions)):
+			self.add_query_param('TLSVersions.' + str(depth1 + 1), TLSVersions[depth1])
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Name(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_Name(self): # String
 		return self.get_query_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
\ No newline at end of file
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
